@@ -3,7 +3,7 @@ Exception classes for TCP
 """
 
 
-class NiryoOneException(Exception):
+class NiryoRobotException(Exception):
     pass
 
 
